angular.module('manageSegmentsApp', [
    'ngRoute',
    'manageSegments',
    'manageProfiles',
    'wemServices',
    'wemDirectives',
    'i18n'
])
    .config(['$routeProvider',
    function($routeProvider) {
        $routeProvider.
            when('/segments', {
                templateUrl: ManagersContext.localTemplatesPath + '/segments/segment-list.html',
                controller: 'ManageSegmentsListCtrl',
                reloadOnSearch: false
            }).
            when('/segment/:segmentId', {
                templateUrl: ManagersContext.localTemplatesPath + '/segments/segment-edit.html',
                controller: 'ManageSegmentsCtrl',
                resolve: {
                    // resolve rule here to avoid async issue using deferred API
                    "currentSegment": function( $q, $route, segmentService) {
                        var segment = $q.defer();
                        segmentService.getSegment($route.current.params.segmentId).success(function (segmentData) {
                            segment.resolve(segmentData);
                        });
                        return segment.promise;
                    },
                    "newSegment": function () {
                        return false;
                    }
                }
            }).
            when('/newSegment', {
                templateUrl: ManagersContext.localTemplatesPath + '/segments/segment-edit.html',
                controller: 'ManageSegmentsCtrl',
                resolve: {
                    "currentSegment": function ($route, segmentService, i18nService) {
                        var segment = {};
                        if(segmentService.segmentToCopy){
                            segment = segmentService.segmentToCopy;
                            segment.metadata.id = ManagersUtils.generateId();
                            segment.metadata.name = i18nService.format('serverSettings.manageSegments.duplicate.name', segmentService.segmentToCopy.metadata.name);
                            delete segmentService.segmentToCopy;
                        } else {
                            segment = {
                                metadata: {
                                    id: ManagersUtils.generateId(),
                                    scope: ManagersContext.dmfScope,
                                    enabled: true
                                },
                                condition: {}
                            }
                        }
                        return segment;
                    },
                    "newSegment": function () {
                        return true;
                    }
                }
            }).
            when('/segment/:segmentId/profiles', {
                templateUrl: ManagersContext.localTemplatesPath + '/segments/profiles-list.html',
                controller: function($scope, profileService) {
                    $scope.exportProfiles = function() {
                        var stringifyQuery = JSON.stringify(angular.copy(profileService.constructQueryOnCurrentSelectedTab(null, 0, -1, null)));
                        profileService.exportUsingForm(stringifyQuery, "segment", "GET");
                    };

                    $scope.profileType='segment';
                }
            }).
            when('/segment/:segmentId/profile/:profileId', {
                templateUrl: ManagersContext.localTemplatesPath + '/profiles/profile-view.html',
                controller: 'ManageProfileCtrl',
                resolve: {
                    // resolve profile here to avoid async issue using deferred API
                    "profile": function ($q, $route, profileService) {
                        var profile = $q.defer();
                        profileService.getProfile($route.current.params.profileId).success(function (profileData) {
                            profile.resolve(profileData);
                        });
                        return profile.promise;
                    }
                }
            }).
            when('/segment/:segmentId/profile/:profileId/:sessionId', {
                templateUrl: ManagersContext.localTemplatesPath + '/profiles/profile-session.html',
                controller: 'ManageSessionCtrl'
            }).
            otherwise({
                redirectTo: '/segments'
            });
    }])
;
