var manageSettings = angular.module('manageSettings', ['i18n', 'wemDirectives', 'wemModals', 'ui-notification']);

manageSettings.config(['NotificationProvider', function (NotificationProvider) {
    NotificationProvider.setOptions({
        delay: 5000,
        startTop: 20,
        startRight: 20,
        verticalSpacing: 20,
        horizontalSpacing: 20,
        positionX: 'right',
        positionY: 'bottom'
    });
}]);

manageSettings.run(['$rootScope', function ($rootScope) {
    $rootScope.settingsUrlAction = ManagersContext.basePreview + ManagersContext.currentSiteHomePagePath + '.wemSettings.do';
}]);

manageSettings.controller('manageSettingsController', ['$scope', '$http', 'i18nService', 'Notification', 'genericModal', function ($scope, $http, i18nService, Notification, genericModal) {
    $scope.show = false;

    $scope.switchShow = function () {
        $scope.show = !$scope.show;
    };

    $scope.$watch(
        function () {
            return $scope.settings != undefined && $scope.settings.publicUrls != undefined && $scope.settings.publicUrls.length > 0;
        },
        function (newValue) {
            $scope.hasSettings = newValue;

        }
    );

    $http.get($scope.settingsUrlAction).
        success(function (data, status, headers, config) {
            $scope.settings = data;
            $scope.hasSettings = $scope.settings.publicUrls != undefined && $scope.settings.publicUrls.length > 0;
        }).
        error(function (data, status, headers, config) {
            Notification.error(i18nService.message('serverSettings.manageSettings.load.error'));
        });

    $scope.save = function () {
        if($scope.settingsForm.$invalid){
            $scope.settingsForm.showErrors = true;

            var parsedErrors = ManagersUtils.parseErrorsInForm($scope.settingsForm);
            if(parsedErrors && Object.keys(parsedErrors).length > 0) {
                ManagersUtils.displayErrors(parsedErrors, i18nService, Notification);
                return;
            }
        }
        doCall({
            method: 'POST',
            url: $scope.settingsUrlAction,
            data: $scope.settings,
            responseType: 'json'
        }, i18nService.message('serverSettings.manageSettings.data.save.ok'), i18nService.message('serverSettings.manageSettings.save.error'));
    };


    $scope.delete = function () {
        doCall({
            method: 'POST',
            url: ManagersContext.basePreview + ManagersContext.currentSiteHomePagePath + '.removeWemSettings.do'
        }, i18nService.message('serverSettings.manageSettings.delete.ok'), i18nService.message('serverSettings.manageSettings.delete.error'));
    };

    $scope.tryPurgeScope = function () {
        var contextServerScope = $scope.settings.contextServerScope;

        // ask confirmation
        genericModal.newAlertModal({
            title: i18nService.format("serverSettings.manageSettings.purge.scope.confirm", contextServerScope),
            bodyMessage: i18nService.format("serverSettings.manageSettings.purge.scope.message", contextServerScope)
        }, function () {
            doCall({
                method: 'DELETE',
                url: ManagersContext.contextServerAdminUrl + '/cxs/cluster/' + contextServerScope
            }, i18nService.message('serverSettings.manageSettings.purge.scope.ok'), i18nService.message('serverSettings.manageSettings.purge.scope.error'), true);
        });
    };

    var doCall = function (config, okMsg, errorMsg, keepSettings) {
        var exceptionToKey = {
            UnknownHostException: {
                key: 'serverSettings.manageSettings.save.error.unknownHost',
                param: $scope.settings.baseContextServerUrl
            },
            '401': {
                key: 'serverSettings.manageSettings.save.error.unauthorized',
                param: $scope.settings.contextServerUsername ? $scope.settings.contextServerUsername : '__void__'
            },
            SSLHandshakeException: {
                key: 'serverSettings.manageSettings.save.error.ssl',
                param: undefined
            }
        };

        var handleError = function (errorMsg, data) {
            // check if we do special handling of the returned exception
            var detail = exceptionToKey[data.type];
            var detailMsg;
            if (detail) {
                detailMsg = ': ' + i18nService.format(detail.key, detail.param);
            }
            else {
                // if we have an error append it to the default error message
                detailMsg = (data.error ? ': ' + data.error : '');
            }
            errorMsg = errorMsg + detailMsg;
            Notification.error(errorMsg);
        };

        $http(config).success(
            function (data) {
                if (data.error == undefined) {
                    Notification.success(okMsg);
                    if (!keepSettings) {
                        $scope.settings = data;
                    }
                } else {
                    handleError(errorMsg, data);
                }
            }
        ).error(function (data) {
                handleError(errorMsg, data);
            });
    };
}]);