var propertyModule = angular.module('property', []);

propertyModule.config(function ($sceDelegateProvider) {

    // we need to normalize the URL as angular uses normalized URLs to check against the whitelist
    var urlParsingNode = document.createElement('a');
    urlParsingNode.setAttribute('href', ManagersContext.contextServerAdminUrl);
    var normalizedContextServerUrl = urlParsingNode.href;

    $sceDelegateProvider.resourceUrlWhitelist([
        // Allow same origin resource loads.
        'self',
        // Allow loading from our assets domain.  Notice the difference between * and **.
            normalizedContextServerUrl + '**'
    ]);

});

propertyModule.directive("property", function () {
    return {
        restrict: "E",
        scope: {
            ref: '=',
            types: '=',
            currentProfile: '='
        },
        template: '<div ng-include="templateUrl"></div>',
        controller: function ($scope) {

            function updateTemplate() {
                if ($scope.ref && $scope.ref.type != "empty") {
                    $scope.valueType = $scope.getValueType($scope.ref);
                    if ($scope.valueType != null) {
                        $scope.templateUrl = ManagersContext.localTemplatesPath + "/values/"+$scope.valueType.id+".html";
                    }
                }
            }

            $scope.getValueType = function (property) {
                for (var i = 0; i < $scope.types.length; i++) {
                    var valueType = $scope.types[i];
                    if (valueType.id == property.type) {
                        return valueType;
                    }
                }
                return null;
            };

            $scope.getPropertyParameterChoiceListValues = function (property, parameterName) {
                var valueType = $scope.getValueType(property);
                if (valueType == null) {
                    return null;
                }

                for (var j = 0; j < valueType.parameters.length; j++) {
                    var parameter = valueType.parameters[j];
                    if (parameter.id == parameterName) {
                        if (parameter.choiceListValues) {
                            return parameter.choiceListValues;
                        } else {
                            return null;
                        }
                    }
                }
                // no matching parameter found
                return null;
            };

            if (!$scope.ref) {
                console.log("property.js: no property passed, creating empty one.");
                $scope.ref = {};
                $scope.ref.type = "empty";
            }

            console.log("property.js: Initializing property controller for property " + $scope.ref + " of type=" + $scope.ref.type);

            updateTemplate();

            $scope.$watch("ref", function (newValue, oldValue) {
                console.log("property.js : property changed, refreshing...");
                updateTemplate();
            });

            $scope.$watch("types.length", function (newValue, oldValue) {
                console.log("property.js : property type list changed, refreshing...");
                updateTemplate();
            });

        }
    };
});